==> birthday_block-1.0.0.tar.gz: birthday_block/src/Controller/BirthdayController.php <==
<?php

namespace Drupal\birthday_block\Controller;

use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Database;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\File\FileUrlGeneratorInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * {@inheritdoc}
 */
class BirthdayController extends ControllerBase {

  /**
   * The file URL generator.
   *
   * @var \Drupal\Core\File\FileUrlGeneratorInterface
   */
  protected $fileUrlGenerator;
  /**
   * User settings config instance.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $userSettings;

  /**
   * Constructs BirthdayController object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   * @param \Drupal\Core\File\FileUrlGeneratorInterface $file_url_generator
   *   The file URL generator.
   * @param \Drupal\Core\Config\ImmutableConfig $user_settings
   *   A user settings config instance.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, FileUrlGeneratorInterface $file_url_generator, ImmutableConfig $user_settings) {
    $this->entityTypeManager = $entity_type_manager;
    $this->fileUrlGenerator = $file_url_generator;
    $this->userSettings = $user_settings;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('file_url_generator'),
      $container->get('config.factory')->get('user.settings'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function content() {
    $content = $this->getBirthdaysData();
    return $content;
  }

  /**
   * {@inheritdoc}
   */
  private function getBirthdaysData($block_content = NULL) {
    $curdate = time();
    $interval_one_week = strtotime('+1 week', $curdate) + 86399;

    $connection = Database::getConnection();
    $query = $connection->select('user__field_dob', 'dob');
    $query->leftJoin('users_field_data', 'u', 'u.uid = dob.entity_id');
    $query->addExpression('UNIX_TIMESTAMP(DATE_ADD(dob.field_dob_value, INTERVAL IF(DAYOFYEAR(dob.field_dob_value) >= DAYOFYEAR(CURDATE() - 1), YEAR(CURDATE()) - YEAR(dob.field_dob_value), YEAR(CURDATE()) - YEAR(dob.field_dob_value) + 1) YEAR))', 'next_birthday');
    $query->fields('dob', ['field_dob_value']);
    $query->fields('u', ['uid']);
    $query->isNotNull('dob.field_dob_value');
    $query->havingCondition('next_birthday', [$curdate, $interval_one_week], 'BETWEEN');
    $query->orderBy('next_birthday', 'ASC');
    $result = $query->execute()->fetchAll();

    $celebration_dob_data = [];
    if (!empty($result)) {
      foreach ($result as $dob_data) {
        if (date('Y-m-d', $dob_data->next_birthday) == date('Y-m-d')) {
          $celebration_dob_data['today'][$dob_data->uid] = $dob_data;
        }
        else {
          $celebration_dob_data['future'][$dob_data->uid] = $dob_data;
        }
      }
    }

    $render_array = [
      '#theme' => 'item_list',
      '#items' => [],
      '#type' => 'ul',
    ];

    if (isset($celebration_dob_data['today']) && count($celebration_dob_data['today'])) {
      $render_array['#items'][] = [
        '#markup' => '<div class="future-birthdays-list">Today</div>',
      ];
      foreach (array_chunk($celebration_dob_data['today'], 2) as $value) {
        $today_birthday_output_list = [];
        foreach ($value as $data) {
          $user = $this->entityTypeManager->getStorage('user')->load($data->uid);

          $first_name = $user->field_first_name->value ?? '';
          $first_name_link = $first_name ? Link::fromTextAndUrl($first_name, Url::fromRoute('entity.user.canonical', ['user' => $data->uid]))->toRenderable() : ['#markup' => ''];
          $user_picture = $user->user_picture->entity ?? NULL;
          $picture_url = $user_picture ? $user_picture->createFileUrl() : $this->fileUrlGenerator->generateAbsoluteString($this->userSettings->get('picture_default') ?? '');
          $today_birthday_output_list[] = $first_name_link;
          $today_birthday_output_list[] = [
            '#theme' => 'image',
            '#uri' => $picture_url,
            '#alt' => $first_name,
            '#width' => '50px',
            '#height' => '50px',
          ];
        }
        $render_array['#items'][] = [
          '#theme' => 'item_list',
          '#items' => $today_birthday_output_list,
          '#type' => 'ul',
        ];
      }
    }

    if (isset($celebration_dob_data['future']) && count($celebration_dob_data['future'])) {
      $render_array['#items'][] = [
        '#markup' => '<div class="future-birthdays-list">Future Birthday Lists.</div>',
      ];
      foreach (array_chunk($celebration_dob_data['future'], 2) as $value) {
        $future_birthday_output_list = [];
        foreach ($value as $data) {
          $user = $this->entityTypeManager->getStorage('user')->load($data->uid);
          $user_picture = $user->user_picture->entity ?? NULL;
          $picture_url = $user_picture ? $user_picture->createFileUrl() : $this->fileUrlGenerator->generateAbsoluteString($this->userSettings->get('picture_default') ?? '');
          $first_name = $user->field_first_name->value ?? '';
          $first_name_link = $first_name ? Link::fromTextAndUrl($first_name, Url::fromRoute('entity.user.canonical', ['user' => $data->uid]))->toRenderable() : ['#markup' => ''];
          $celebration_date = date('Y-m-d', $data->next_birthday) == date('Y-m-d') ? 'Today' : date('d M', $data->next_birthday);
          $future_birthday_output_list[] = $first_name_link;
          $future_birthday_output_list[] = [
            '#theme' => 'image',
            '#uri' => $picture_url,
            '#alt' => $first_name,
          ];
          $future_birthday_output_list[] = [
            '#markup' => $celebration_date,
          ];
        }
        $render_array['#items'][] = [
          '#theme' => 'item_list',
          '#items' => $future_birthday_output_list,
          '#type' => 'ul',
          '#cache' => ['max-age' => 0],
        ];
      }
    }

    if ($block_content) {
      return $celebration_dob_data;
    }
    else {
      return $render_array;
    }
  }

}

==> birthday_block-1.0.2.tar.gz: birthday_block/src/Controller/BirthdayController.php <==
<?php

namespace Drupal\birthday_block\Controller;

use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Database;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\File\FileUrlGeneratorInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class Initialization.
 *
 * @package Drupal\birthday_block\Controller
 */
class BirthdayController extends ControllerBase {

  /**
   * The file URL generator.
   *
   * @var \Drupal\Core\File\FileUrlGeneratorInterface
   */
  protected $fileUrlGenerator;

  /**
   * User settings config instance.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $userSettings;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs BirthdayController object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   * @param \Drupal\Core\File\FileUrlGeneratorInterface $file_url_generator
   *   The file URL generator.
   * @param \Drupal\Core\Config\ImmutableConfig $user_settings
   *   A user settings config instance.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, FileUrlGeneratorInterface $file_url_generator, ImmutableConfig $user_settings) {
    $this->entityTypeManager = $entity_type_manager;
    $this->fileUrlGenerator = $file_url_generator;
    $this->userSettings = $user_settings;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('file_url_generator'),
      $container->get('config.factory')->get('user.settings')
    );
  }

  /**
   * Display birthdays.
   *
   * @return array
   *   Render array.
   */
  public function content() {
    $birthdays_data = $this->getBirthdaysData();
    return [
      '#theme' => 'birthday_list',
      '#birthdays' => $birthdays_data,
    ];
  }

  /**
   * Get birthdays data.
   *
   * @return array
   *   An array of birthdays.
   */
  private function getBirthdaysData() {
    // Normalize current date to midnight.
    $curdate = strtotime('today');
    $interval_one_week = strtotime('+1 week', $curdate) + 86399;

    $connection = Database::getConnection();
    $query = $connection->select('user__field_dob', 'dob');
    $query->leftJoin('users_field_data', 'u', 'u.uid = dob.entity_id');
    $query->addExpression('UNIX_TIMESTAMP(DATE_ADD(dob.field_dob_value, INTERVAL IF(DAYOFYEAR(dob.field_dob_value) >= DAYOFYEAR(CURDATE() - 1), YEAR(CURDATE()) - YEAR(dob.field_dob_value), YEAR(CURDATE()) - YEAR(dob.field_dob_value) + 1) YEAR))', 'next_birthday');
    $query->fields('dob', ['field_dob_value']);
    $query->fields('u', ['uid']);
    $query->isNotNull('dob.field_dob_value');
    $query->havingCondition('next_birthday', [$curdate, $interval_one_week], 'BETWEEN');
    $query->orderBy('next_birthday', 'ASC');
    $result = $query->execute()->fetchAll();

    // Output the actual SQL query for debugging.
    $result = $query->execute()->fetchAll();

    $celebration_dob_data = [
      'today' => [],
      'future' => [],
    ];

    foreach ($result as $dob_data) {
      $user = $this->entityTypeManager->getStorage('user')->load($dob_data->uid);
      if ($user) {
        $first_name = $user->field_first_name->value ?? '';
        $user_picture = $user->user_picture->entity ?? NULL;
        $picture_url = $user_picture ? $user_picture->createFileUrl() : $this->fileUrlGenerator->generateAbsoluteString($this->userSettings->get('picture_default') ?? '');
        $user_data = [
          'name' => $first_name,
          'profile_url' => Url::fromRoute('entity.user.canonical', ['user' => $dob_data->uid])->toString(),
          'picture_url' => $picture_url,
          'birthday' => date('d M', $dob_data->next_birthday),
        ];

        if (date('Y-m-d', $dob_data->next_birthday) == date('Y-m-d', $curdate)) {
          $celebration_dob_data['today'][] = $user_data;
        }
        else {
          $celebration_dob_data['future'][] = $user_data;
        }
      }
    }

    return $celebration_dob_data;
  }

}
